@@ -6,7 +6,7 @@ use warnings;
 use AI::NeuralNet::FastSOM;
 our @ISA = qw/AI::NeuralNet::FastSOM/;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub _old_radius { shift->{_R} }
 
@@ -38,21 +38,21 @@ sub as_string {
 
     $s .= "    ";
     for my $y (0 .. $self->{_Y}-1){
-        $s .= sprintf ("   %02d ",$y);
+        $s .= sprintf("   %02d ",$y);
     }
-    $s .= sprintf "\n","-"x107,"\n";
+    $s .= "\n" . "-"x107 . "\n";
 
     my $dim = scalar @{ $self->{map}->[0]->[0] };
 
     for my $x (0 .. $self->{_X}-1) {
         for my $w ( 0 .. $dim-1 ){
-            $s .= sprintf ("%02d | ",$x);
+            $s .= sprintf("%02d | ",$x);
             for my $y (0 .. $self->{_Y}-1){
-                $s .= sprintf ("% 2.2f ", $self->{map}->[$x]->[$y]->[$w]);
+                $s .= sprintf("% 2.2f ", $self->{map}->[$x]->[$y]->[$w]);
             }
-            $s .= sprintf "\n";
+            $s .= "\n";
         }
-        $s .= sprintf "\n";
+        $s .= "\n";
     }
     return $s;
 }
@@ -65,9 +65,9 @@ sub as_data {
     for my $x (0 .. $self->{_X}-1) {
         for my $y (0 .. $self->{_Y}-1){
             for my $w ( 0 .. $dim-1 ){
-                $s .= sprintf ("\t%f", $self->{map}->[$x]->[$y]->[$w]);
+                $s .= sprintf("\t%f", $self->{map}->[$x]->[$y]->[$w]);
             }
-            $s .= sprintf "\n";
+            $s .= "\n";
         }
     }
     return $s;
